@@ -798,7 +798,7 @@ void DocumentHandler::saveAs(const QUrl &url)
     // 	}
     
     const QString filePath = url.toLocalFile();
-    const bool isHtml = QFileInfo(filePath).suffix().contains(QLatin1String("htm"));
+    const bool isHtml = QFileInfo(filePath).suffix().contains(QLatin1String("html"));
     QFile file(filePath);
     if (!file.open(QFile::WriteOnly | QFile::Truncate | (isHtml ? QFile::NotOpen : QFile::Text))) {
         emit error(i18nd("mauikittexteditor","Cannot save: ") + file.errorString());
@@ -840,17 +840,6 @@ const QStringList DocumentHandler::getLanguageNameList()
     });
 }
 
-const QStringList DocumentHandler::getThemes()
-{
-    if (!DocumentHandler::m_repository)
-        DocumentHandler::m_repository = new KSyntaxHighlighting::Repository();
-    
-    const auto themes = DocumentHandler::m_repository->themes();
-    return std::accumulate(themes.constBegin(), themes.constEnd(), QStringList(), [](QStringList &res, const KSyntaxHighlighting::Theme &theme) -> QStringList {
-        res << theme.name();
-        return res;
-    });
-}
 
 void DocumentHandler::reset()
 {
