@@ -13,21 +13,18 @@ class TextEditorPlugin : public QQmlExtensionPlugin
     Q_PLUGIN_METADATA(IID QQmlExtensionInterface_iid)
 public:
     void registerTypes(const char *uri) override;
-private:
-    QString resolveFilePath(const QString &path) const
-    {
-#if defined(Q_OS_ANDROID)
-        return QStringLiteral(":/android_rcc_bundle/qml/org/mauikit/texteditor/") + path;
-#else
-        return baseUrl().toLocalFile() + QLatin1Char('/') + path;
-#endif
-    }
+private:    
+
     QString resolveFileUrl(const QString &filePath) const
     {
 #if defined(Q_OS_ANDROID)
         return QStringLiteral("qrc:/android_rcc_bundle/qml/org/mauikit/texteditor/") + filePath;
+#else
+#ifdef QUICK_COMPILER
+        return QStringLiteral("qrc:/mauikit/texteditor/") + filePath;
 #else
         return baseUrl().toString() + QLatin1Char('/') + filePath;
+#endif
 #endif
     }
 };
